@@ -37,24 +37,16 @@
 #include <string.h>
 #include "util.h"
 
-#include "gtk-compat.h"
-#include "gdk2-drawing-utils.h"
-
-#ifdef USE_GTK3
 static void     meta_accel_label_destroy      (GtkWidget           *object);
-#else
-static void     meta_accel_label_destroy      (GtkObject           *object);
-#endif
 static void     meta_accel_label_finalize     (GObject             *object);
-static void     meta_accel_label_size_request (GtkWidget           *widget,
-                                               GtkRequisition      *requisition);
-#ifdef USE_GTK3
+static void     meta_accel_label_get_preferred_width  (GtkWidget *widget,
+                                                       gint      *minimum,
+                                                       gint      *natural);
+static void     meta_accel_label_get_preferred_height (GtkWidget *widget,
+                                                       gint      *minimum,
+                                                       gint      *natural);
 static gboolean meta_accel_label_draw         (GtkWidget           *widget,
                                                cairo_t             *cr);
-#else
-static gboolean meta_accel_label_expose_event (GtkWidget           *widget,
-                                               GdkEventExpose      *event);
-#endif
 
 static void  meta_accel_label_update          (MetaAccelLabel *accel_label);
 static int   meta_accel_label_get_accel_width (MetaAccelLabel *accel_label);
@@ -69,18 +61,11 @@ meta_accel_label_class_init (MetaAccelLabelClass *class)
 
   gobject_class->finalize = meta_accel_label_finalize;
 
-#ifdef USE_GTK3
   widget_class->destroy = meta_accel_label_destroy;
-#else
-  GTK_OBJECT_CLASS (class)->destroy = meta_accel_label_destroy;
-#endif
 
-  widget_class->size_request = meta_accel_label_size_request;
-#ifdef USE_GTK3
+  widget_class->get_preferred_width = meta_accel_label_get_preferred_width;
+  widget_class->get_preferred_height = meta_accel_label_get_preferred_height;
   widget_class->draw = meta_accel_label_draw;
-#else
-  widget_class->expose_event = meta_accel_label_expose_event;
-#endif
 
   class->signal_quote1 = g_strdup ("<:");
   class->signal_quote2 = g_strdup (":>");
@@ -173,13 +158,8 @@ meta_accel_label_new_with_mnemonic (const gchar *string)
   return GTK_WIDGET (accel_label);
 }
 
-#ifdef USE_GTK3
 static void
 meta_accel_label_destroy (GtkWidget *object)
-#else
-static void
-meta_accel_label_destroy (GtkObject *object)
-#endif
 {
   MetaAccelLabel *accel_label = META_ACCEL_LABEL (object);
 
@@ -190,11 +170,7 @@ meta_accel_label_destroy (GtkObject *object)
   accel_label->accel_mods = 0;
   accel_label->accel_key = 0;
 
-#ifdef USE_GTK3
   GTK_WIDGET_CLASS (meta_accel_label_parent_class)->destroy (object);
-#else
-  GTK_OBJECT_CLASS (meta_accel_label_parent_class)->destroy (object);
-#endif
 }
 
 static void
@@ -234,15 +210,15 @@ meta_accel_label_get_accel_width (MetaAccelLabel *accel_label)
 }
 
 static void
-meta_accel_label_size_request (GtkWidget	     *widget,
-			      GtkRequisition *requisition)
+meta_accel_label_get_preferred_width (GtkWidget *widget,
+                                      gint      *minimum,
+                                      gint      *natural)
 {
   MetaAccelLabel *accel_label = META_ACCEL_LABEL (widget);
   PangoLayout *layout;
   gint width;
 
-  if (GTK_WIDGET_CLASS (meta_accel_label_parent_class)->size_request)
-    GTK_WIDGET_CLASS (meta_accel_label_parent_class)->size_request (widget, requisition);
+  GTK_WIDGET_CLASS (meta_accel_label_parent_class)->get_preferred_width (widget, minimum, natural);
 
   layout = gtk_widget_create_pango_layout (widget, accel_label->accel_string);
   pango_layout_get_pixel_size (layout, &width, NULL);
@@ -251,7 +227,14 @@ meta_accel_label_size_request (GtkWidget	     *widget,
   g_object_unref (G_OBJECT (layout));
 }
 
-#ifdef USE_GTK3
+static void
+meta_accel_label_get_preferred_height (GtkWidget *widget,
+                                       gint      *minimum,
+                                       gint      *natural)
+{
+  GTK_WIDGET_CLASS (meta_accel_label_parent_class)->get_preferred_height (widget, minimum, natural);
+}
+
 /* Mostly taken from GTK3. */
 static gboolean
 meta_accel_label_draw (GtkWidget *widget,
@@ -272,6 +255,7 @@ meta_accel_label_draw (GtkWidget *widget,
 
   if (allocation.width >= requisition.width + ac_width)
     {
+      GtkStyleContext *style;
       PangoLayout *label_layout;
       PangoLayout *accel_layout;
       GtkLabel *label = GTK_LABEL (widget);
@@ -319,14 +303,15 @@ meta_accel_label_draw (GtkWidget *widget,
 
       y = (allocation.height - (requisition.height - ypad * 2)) * yalign + 1.5;
 
-      gtk_paint_layout (gtk_widget_get_style (widget),
-                        cr,
-                        gtk_widget_get_state (widget),
-                        FALSE,
-                        widget,
-                        "accellabel",
-                        x, y,
-                        accel_layout);                            
+      style = gtk_widget_get_style_context (widget);
+      gtk_style_context_save (style);
+      gtk_style_context_set_state (style,
+                                   gtk_widget_get_state_flags (widget));
+      gtk_render_layout (gtk_widget_get_style_context (widget),
+                         cr,
+                         x, y,
+                         accel_layout);
+      gtk_style_context_restore (style);
 
       g_object_unref (accel_layout);
     }
@@ -338,89 +323,6 @@ meta_accel_label_draw (GtkWidget *widget,
   
   return FALSE;
 }
-#else /* !USE_GTK3 */
-static gboolean
-meta_accel_label_expose_event (GtkWidget      *widget,
-			      GdkEventExpose *event)
-{
-  MetaAccelLabel *accel_label = META_ACCEL_LABEL (widget);
-  GtkMisc *misc = GTK_MISC (accel_label);
-  PangoLayout *layout;
-
-  if (gtk_widget_is_drawable (GTK_WIDGET (accel_label)))
-    {
-      GtkAllocation allocation;
-      GtkRequisition requisition;
-      int ac_width;
-
-      gtk_widget_get_allocation (widget, &allocation);
-      gtk_widget_get_requisition (widget, &requisition);
-      ac_width = meta_accel_label_get_accel_width (accel_label);
-
-      if (allocation.width >= requisition.width + ac_width)
-	{
-          GtkTextDirection direction = gtk_widget_get_direction (widget);
-          gfloat xalign, yalign;
-          gint x, y;
-          gint xpad, ypad;
-
-          gtk_misc_get_padding (misc, &xpad, &ypad);
-          gtk_misc_get_alignment (misc, &xalign, &yalign);
-
-          if (direction == GTK_TEXT_DIR_RTL)
-            {
-              allocation.x += ac_width;
-            }
-          allocation.width -= ac_width;
-          gtk_widget_set_allocation (widget, &allocation);
-
-	  if (GTK_WIDGET_CLASS (meta_accel_label_parent_class)->expose_event)
-	    GTK_WIDGET_CLASS (meta_accel_label_parent_class)->expose_event (widget, event);
-
-          if (direction == GTK_TEXT_DIR_RTL)
-            {
-              allocation.x -= ac_width;
-            }
-          allocation.width += ac_width;
-          gtk_widget_set_allocation (widget, &allocation);
-
-          if (direction == GTK_TEXT_DIR_RTL)
-            {
-              x = allocation.x + xpad;
-            }
-          else
-            {
-              x = allocation.x + allocation.width - xpad - ac_width;
-            }
-
-	  y = (allocation.y * (1.0 - yalign) +
-	       (allocation.y + allocation.height -
-		(requisition.height - ypad * 2)) * yalign) + 1.5;
-
-	  layout = gtk_widget_create_pango_layout (widget, accel_label->accel_string);
-
-          gtk_paint_layout (gtk_widget_get_style (widget),
-                            gtk_widget_get_window (widget),
-                            gtk_widget_get_state (widget),
-			    FALSE,
-                            &event->area,
-                            widget,
-                            "accellabel",
-                            x, y,
-                            layout);
-
-          g_object_unref (G_OBJECT (layout));
-	}
-      else
-	{
-	  if (GTK_WIDGET_CLASS (meta_accel_label_parent_class)->expose_event)
-	    GTK_WIDGET_CLASS (meta_accel_label_parent_class)->expose_event (widget, event);
-	}
-    }
-
-  return FALSE;
-}
-#endif /* !USE_GTK3 */
 
 static void
 meta_accel_label_update (MetaAccelLabel *accel_label)
